@@ -411,12 +411,6 @@ See the L<utime|https://linux.die.net/man/2/utime> function in Linux.
 
 The buf is a L<Sys::IO::Utimbuf|SPVM::Sys::IO::Utimbuf> object.
 
-=head2 access_raw
-
-C<static method access_raw : int ($pathname : string, $mode : int);>
-
-The same as L</"access">, but even if the return value is C<-1>, an exception will not be thrown.
-
 =head2 access
 
 C<static method access : int ($pathname : string, $mode : int);>
@@ -427,12 +421,6 @@ See the L<access|https://linux.die.net/man/2/access> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the mode.
 
-=head2 eaccess_raw
-
-C<static method eaccess_raw : int ($pathname : string, $mode : int);>
-
-The same as L</"eaccess">, but even if the return value is C<-1>, an exception will not be thrown.
-
 =head2 eaccess
 
 C<static method eaccess : int ($pathname : string, $mode : int);>
@@ -441,19 +429,17 @@ eaccess() checks whether the calling process can eaccess the file pathname. If p
 
 See the L<eaccess|https://linux.die.net/man/3/eaccess> function in Linux.
 
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the C<$mode>.
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the $mode.
 
-=head2 eaccess_raw
+=head2 faccessat
 
-C<static method eaccess : int ($pathname : string, $mode : int)>
+  static method faccessat : int ($dirfd : int, $pathname : string, $mode : int, $flags : int);
 
-The same as L</"eaccess">, but even if the return value is C<-1>, an exception will not be thrown.
+check user's permissions of a file relative to a directory file descriptor.
 
-=head2 eaccess
+See the L<faccessat|https://linux.die.net/man/2/faccessat> function in Linux.
 
-C<static method eaccess : int ($pathname : string, $mode : int)>
-
-Emulates C<eaccess> using L</"faccessat">.
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the $mode and $flag.
 
 =head2 stat_raw
 
