@@ -28,7 +28,7 @@ See L<gettimeofday(2) - Linux man page|https://linux.die.net/man/2/gettimeofday>
 
 =head2 new
 
-  static method new : Sys::Time::Timezone ()
+C<static method new : L<Sys::Time::Timezone|SPVM::Sys::Time::Timezone> ()>
 
 Creates a new C<Sys::Time::Timezone> object.
 
@@ -38,7 +38,7 @@ Creates a new C<Sys::Time::Timezone> object.
 
 =head2 tz_minuteswest
 
-  method tz_minuteswest : int ()
+C<method tz_minuteswest : int ()>
 
 Gets C<tz_minuteswest>.
 
@@ -46,7 +46,7 @@ Gets C<tz_minuteswest>.
 
 =head2 set_tz_minuteswest
 
-  method set_tz_minuteswest : void ($tz_minuteswest : int)
+C<method set_tz_minuteswest : void ($tz_minuteswest : int)>
 
 Sets C<tz_minuteswest>.
 
@@ -54,7 +54,7 @@ Sets C<tz_minuteswest>.
 
 =head2 tz_dsttime
   
-  method tz_dsttime : int ()
+C<method tz_dsttime : int ()>
 
 Gets C<tz_dsttime>.
 
@@ -62,7 +62,7 @@ Gets C<tz_dsttime>.
 
 =head2 set_tz_dsttime
 
-  method set_tz_dsttime : void ($tz_dsttime : int)
+C<method set_tz_dsttime : void ($tz_dsttime : int)>
 
 Sets C<tz_dsttime>.
 
